@@ -65,52 +65,6 @@ ch_date_subset <- function(df, prd) {
   return(df)
 }
 
-#' Adjusts colour codes to introduce transparency
-#'
-#' \code{ch_col_transparent} is used to adjust colour codes to introduce transparency.
-#'
-#' @param colour Vector of colours you wish to add transparency to.
-#' @param trans Integer(s) describing the degree of transparency, from ~200
-#' (slightly transparent) to <10 (very transparent).
-#' @return \item{res}{returned updated colour code with transparency}
-#' 
-#' @seealso See original code on post in Stack Overflow
-#' \href{http://stackoverflow.com/questions/12995683/any-way-to-make-plot-points-in-scatterplot-more-transparent-in-rmaking}{
-#' plot points transparent in R}
-#' 
-#' @keywords colour transparency
-#' @examples
-#'
-#' # plot randomly distributed data
-#' plot(rnorm(20),col='black')
-#'
-#' # create a transparent blue colour for plotting
-#' mycol <- ch_col_transparent('blue',100)
-#'
-#' # plot more random points in transparent blue colour
-#' points(rnorm(20),col=mycol)
-#' 
-#' # add transparency to multiple colours
-#' ch_col_transparent( c('red','blue','green'), c(50,100,200))
-#'
-#' @importFrom grDevices col2rgb
-#' @export ch_col_transparent
-ch_col_transparent <- function(colour, trans)
-{
-  
-  if (length(colour) != length(trans) & !any(c(length(colour),length(trans)) == 1)) stop("Vector lengths not correct")
-  if (length(colour) == 1 & length(trans) > 1) colour <- rep(colour,length(trans))
-  if (length(trans) == 1 & length(colour) > 1) trans <- rep(trans,length(colour))
-  
-  num2hex <- function(x)
-  {
-    hex <- unlist(strsplit("0123456789ABCDEF",split = ""))
-    return(paste(hex[(x - x %% 16)/16 + 1],hex[x %% 16 + 1],sep = ""))
-  }
-  rgb <- rbind(col2rgb(colour),trans)
-  res <- paste("#",apply(apply(rgb,2,num2hex),2,paste,collapse = ""),sep = "")
-  return(res)
-}
 
 #' Tests url to see if it will work
 #'
